@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,10 +42,7 @@ static const GType ColumnTypes[] = {
   G_TYPE_POINTER  /* PeasPluginInfo */
 };
 
-/* G_STATIC_ASSERT is in glib >= 2.20 and we only depend on 2.18.0 */
-#ifdef G_STATIC_ASSERT
 G_STATIC_ASSERT (G_N_ELEMENTS (ColumnTypes) == PEAS_GTK_PLUGIN_MANAGER_STORE_N_COLUMNS);
-#endif
 
 struct _PeasGtkPluginManagerStorePrivate {
   PeasEngine *engine;
@@ -54,9 +51,12 @@ struct _PeasGtkPluginManagerStorePrivate {
 /* Properties */
 enum {
   PROP_0,
-  PROP_ENGINE
+  PROP_ENGINE,
+  N_PROPERTIES
 };
 
+static GParamSpec *properties[N_PROPERTIES] = { NULL };
+
 G_DEFINE_TYPE (PeasGtkPluginManagerStore, peas_gtk_plugin_manager_store, GTK_TYPE_LIST_STORE);
 
 static void
@@ -259,8 +259,7 @@ peas_gtk_plugin_manager_store_constructed (GObject *object)
 
   peas_gtk_plugin_manager_store_reload (store);
 
-  if (G_OBJECT_CLASS (peas_gtk_plugin_manager_store_parent_class)->constructed != NULL)
-    G_OBJECT_CLASS (peas_gtk_plugin_manager_store_parent_class)->constructed (object);
+  G_OBJECT_CLASS (peas_gtk_plugin_manager_store_parent_class)->constructed (object);
 }
 
 static void
@@ -273,9 +272,7 @@ peas_gtk_plugin_manager_store_dispose (GObject *object)
       g_signal_handlers_disconnect_by_func (store->priv->engine,
                                             plugin_loaded_toggled_cb,
                                             store);
-
-      g_object_unref (store->priv->engine);
-      store->priv->engine = NULL;
+      g_clear_object (&store->priv->engine);
     }
 
   G_OBJECT_CLASS (peas_gtk_plugin_manager_store_parent_class)->dispose (object);
@@ -296,16 +293,16 @@ peas_gtk_plugin_manager_store_class_init (PeasGtkPluginManagerStoreClass *klass)
    *
    * The #PeasEngine this store is attached to.
    */
-  g_object_class_install_property (object_class,
-                                   PROP_ENGINE,
-                                   g_param_spec_object ("engine",
-                                                        "engine",
-                                                        "The PeasEngine this store is attached to",
-                                                        PEAS_TYPE_ENGINE,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY |
-                                                        G_PARAM_STATIC_STRINGS));
+  properties[PROP_ENGINE] =
+    g_param_spec_object ("engine",
+                         "engine",
+                         "The PeasEngine this store is attached to",
+                         PEAS_TYPE_ENGINE,
+                         G_PARAM_READWRITE |
+                         G_PARAM_CONSTRUCT_ONLY |
+                         G_PARAM_STATIC_STRINGS);
 
+  g_object_class_install_properties (object_class, N_PROPERTIES, properties);
   g_type_class_add_private (object_class, sizeof (PeasGtkPluginManagerStorePrivate));
 }
 
