@@ -117,18 +117,20 @@ enum {
   LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL];
-
 /* Properties */
 enum {
   PROP_0,
   PROP_ENGINE,
   PROP_EXTENSION_TYPE,
-  PROP_CONSTRUCT_PROPERTIES
+  PROP_CONSTRUCT_PROPERTIES,
+  N_PROPERTIES
 };
 
+static guint signals[LAST_SIGNAL];
+static GParamSpec *properties[N_PROPERTIES] = { NULL };
+
 static void
-set_construct_properties (PeasExtensionSet *set,
+set_construct_properties (PeasExtensionSet   *set,
                           PeasParameterArray *array)
 {
   unsigned i;
@@ -276,6 +278,8 @@ peas_extension_set_constructed (GObject *object)
           g_signal_connect_data (set->priv->engine, "unload-plugin",
                                  G_CALLBACK (remove_extension), set,
                                  NULL, G_CONNECT_SWAPPED);
+
+  G_OBJECT_CLASS (peas_extension_set_parent_class)->constructed (object);
 }
 
 static void
@@ -296,10 +300,13 @@ peas_extension_set_dispose (GObject *object)
       set->priv->unload_handler_id = 0;
     }
 
-  for (l = set->priv->extensions; l;)
+  if (set->priv->extensions != NULL)
     {
-      remove_extension_item (set, (ExtensionItem *) l->data);
-      l = g_list_delete_link (l, l);
+      for (l = set->priv->extensions; l != NULL; l = l->next)
+        remove_extension_item (set, (ExtensionItem *) l->data);
+
+      g_list_free (set->priv->extensions);
+      set->priv->extensions = NULL;
     }
 
   if (set->priv->parameters != NULL)
@@ -311,11 +318,7 @@ peas_extension_set_dispose (GObject *object)
       set->priv->parameters = NULL;
     }
 
-  if (set->priv->engine != NULL)
-    {
-      g_object_unref (set->priv->engine);
-      set->priv->engine = NULL;
-    }
+  g_clear_object (&set->priv->engine);
 }
 
 static gboolean
@@ -404,32 +407,33 @@ peas_extension_set_class_init (PeasExtensionSetClass *klass)
                   PEAS_TYPE_PLUGIN_INFO | G_SIGNAL_TYPE_STATIC_SCOPE,
                   PEAS_TYPE_EXTENSION);
 
-  g_object_class_install_property (object_class, PROP_ENGINE,
-                                   g_param_spec_object ("engine",
-                                                        "Engine",
-                                                        "The PeasEngine this set is attached to",
-                                                        PEAS_TYPE_ENGINE,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY |
-                                                        G_PARAM_STATIC_STRINGS));
+  properties[PROP_ENGINE] =
+    g_param_spec_object ("engine",
+                         "Engine",
+                         "The PeasEngine this set is attached to",
+                         PEAS_TYPE_ENGINE,
+                         G_PARAM_READWRITE |
+                         G_PARAM_CONSTRUCT_ONLY |
+                         G_PARAM_STATIC_STRINGS);
 
-  g_object_class_install_property (object_class, PROP_EXTENSION_TYPE,
-                                   g_param_spec_gtype ("extension-type",
-                                                       "Extension Type",
-                                                       "The extension GType managed by this set",
-                                                       G_TYPE_NONE,
-                                                       G_PARAM_READWRITE |
-                                                       G_PARAM_CONSTRUCT_ONLY |
-                                                       G_PARAM_STATIC_STRINGS));
+  properties[PROP_EXTENSION_TYPE] =
+    g_param_spec_gtype ("extension-type",
+                        "Extension Type",
+                        "The extension GType managed by this set",
+                        G_TYPE_NONE,
+                        G_PARAM_READWRITE |
+                        G_PARAM_CONSTRUCT_ONLY |
+                        G_PARAM_STATIC_STRINGS);
 
-  g_object_class_install_property (object_class, PROP_CONSTRUCT_PROPERTIES,
-                                   g_param_spec_pointer ("construct-properties",
-                                                         "Construct Properties",
-                                                         "The properties to pass the extensions when creating them",
-                                                         G_PARAM_WRITABLE |
-                                                         G_PARAM_CONSTRUCT_ONLY |
-                                                         G_PARAM_STATIC_STRINGS));
+  properties[PROP_CONSTRUCT_PROPERTIES] =
+    g_param_spec_pointer ("construct-properties",
+                          "Construct Properties",
+                          "The properties to pass the extensions when creating them",
+                          G_PARAM_WRITABLE |
+                          G_PARAM_CONSTRUCT_ONLY |
+                          G_PARAM_STATIC_STRINGS);
 
+  g_object_class_install_properties (object_class, N_PROPERTIES, properties);
   g_type_class_add_private (klass, sizeof (PeasExtensionSetPrivate));
 }
 
@@ -464,7 +468,7 @@ peas_extension_set_get_extension (PeasExtensionSet *set,
 }
 
 /**
- * peas_extension_set_call: (skip)
+ * peas_extension_set_call:
  * @set: A #PeasExtensionSet.
  * @method_name: the name of the method that should be called.
  * @...: arguments for the method.
@@ -473,7 +477,7 @@ peas_extension_set_get_extension (PeasExtensionSet *set,
  *
  * See peas_extension_call() for more information.
  *
- * Deprecated: 1.2. Use peas_extension_set_foreach() instead.
+ * Deprecated: 1.2: Use peas_extension_set_foreach() instead.
  *
  * Return value: %TRUE on successful call.
  */
@@ -496,7 +500,7 @@ peas_extension_set_call (PeasExtensionSet *set,
 }
 
 /**
- * peas_extension_set_call_valist: (skip)
+ * peas_extension_set_call_valist:
  * @set: A #PeasExtensionSet.
  * @method_name: the name of the method that should be called.
  * @va_args: the arguments for the method.
@@ -505,7 +509,7 @@ peas_extension_set_call (PeasExtensionSet *set,
  *
  * See peas_extension_call_valist() for more information.
  *
- * Deprecated: 1.2. Use peas_extension_set_foreach() instead.
+ * Deprecated: 1.2: Use peas_extension_set_foreach() instead.
  *
  * Return value: %TRUE on successful call.
  */
@@ -523,9 +527,12 @@ peas_extension_set_call_valist (PeasExtensionSet *set,
 
   callable_info = peas_gi_get_method_info (set->priv->exten_type, method_name);
 
-  /* Already warned */
   if (callable_info == NULL)
-    return FALSE;
+    {
+      g_warning ("Method '%s.%s' was not found",
+                 g_type_name (set->priv->exten_type), method_name);
+      return FALSE;
+    }
 
   n_args = g_callable_info_get_n_args (callable_info);
   g_return_val_if_fail (n_args >= 0, FALSE);
@@ -550,9 +557,7 @@ peas_extension_set_call_valist (PeasExtensionSet *set,
  *
  * Return value: %TRUE on successful call.
  *
- * Deprecated: 1.2. Use peas_extension_set_foreach() instead.
- *
- * Rename to: peas_extension_set_call
+ * Deprecated: 1.2: Use peas_extension_set_foreach() instead.
  */
 gboolean
 peas_extension_set_callv (PeasExtensionSet *set,
