@@ -225,7 +225,6 @@ test_engine_not_loadable_plugin (PeasEngine *engine)
 
   testing_util_push_log_hook ("*libnot-loadable.so: cannot open shared "
                               "object file: No such file or directory");
-  testing_util_push_log_hook ("Could not load plugin module: 'not-loadable'");
   testing_util_push_log_hook ("Error loading plugin 'not-loadable'");
 
   info = peas_engine_get_plugin_info (engine, "not-loadable");
@@ -362,7 +361,8 @@ test_engine_nonexistent_loader (PeasEngine *engine)
   GError *error = NULL;
   PeasPluginInfo *info;
 
-  testing_util_push_log_hook ("Could not find loader 'does-not-exist'*");
+  testing_util_push_log_hook ("Could not load plugin loader 'does-not-exist'*");
+  testing_util_push_log_hook ("Could not find loader 'does-not-exist' for*");
 
   info = peas_engine_get_plugin_info (engine, "nonexistent-loader");
   peas_engine_enable_loader (engine, "does-not-exist");
